from sensor.Sensor import Sensor
from utils.datatypes import *
from utils import i18n
import time
import os

import libdesklets

class CPU(Sensor):

	def __init__(self, interval = "500"):
		
		global _; _ = i18n.Translator("cpu-sensor")
		
		self.__model_name = ""
		self.__cpu_mhz = ""
		self.__load = 0
		
		Sensor.__init__(self)
		
		self._set_config_type("update", TYPE_INT, int(interval))
		
		self._add_timer(int(interval), self.__on_tick)
		self._add_thread(self.__command_thread)
		
		#Get 'static' infos
		self.__model_name = libdesklets.cpu.get_model()
		self.__cpu_mhz = libdesklets.cpu.get_speed()
		self.__cache = libdesklets.cpu.get_cache_size()

	def __on_tick(self):
		data = self._new_output()
		
		data.set("load", self.__load)
		data.set("model", self.__model_name)
		data.set("cpumhz", self.__cpu_mhz)
		data.set("cache", self.__cache)
		
		self._send_output(data)
		
		return 1

	def get_configurator(self):
		configurator = self._new_configurator()
		configurator.set_name(_("CPU load"))
		configurator.add_title(_("Refresh"))
		configurator.add_spin(_("Update every (ms):"), "update",
					_("Updates the CPU load every x milliseconds"),
					100, 60000)
		return configurator
	
	def __command_thread(self):
		while (1):
			if (self._is_stopped()): break
			
			self.__load = libdesklets.cpu.get_load()[1]
			time.sleep(self._get_config("update")*0.001)
				


def new_sensor(args): return apply(CPU, args)
