from sensor.Sensor import Sensor
from utils.datatypes import *
from utils import i18n

import time
import os
import commands

class Ping(Sensor):

	def __init__(self, interval = "1000"):
		
		global _; _ = i18n.Translator("ping-sensor")
		
		self.__max_ping = 0.0
		self.__min_ping = 0.0
		self.__last_error = 0
		self.__last_ping = 0.0
		self.__targets = "127.0.0.1"
		Sensor.__init__(self)
		
		self._set_config_type("update", TYPE_INT, int(interval))
		self._set_config_type("target", TYPE_STRING, "127.0.0.1")
		
		self._add_timer(500, self.__on_tick)
		self._add_thread(self.__command_thread)

	def __on_tick(self):
		data = self._new_output()
		
		data.set("target", self._get_config("target"))
		data.set("ping", self.__last_ping)
		data.set("min", self.__min_ping)
		data.set("max", self.__max_ping)
		if (self.__last_error == 0):
			data.set("error", 0)
			data.set("noterror", 1)
		else :
			data.set("error", 1)
			data.set("noterror", 0)
			
		self._send_output(data)
		
		return 1
		
	def get_configurator(self):
		configurator = self._new_configurator()
		configurator.set_name(_("Ping"))
		configurator.add_title(_("Display Configuration"))
		configurator.add_spin(_("Update every (ms):"), "update",
					_("Updates the ping every x milliseconds"),
					500, 3600000)
		configurator.add_entry(_("Target:"), "target",
					_("The server to ping"))
		return configurator
	
	def __command_thread(self):
		while (1):
			if (self._is_stopped()): break
			
			curtarg = self._get_config("target")
			
			if (self.__targets != curtarg):
				self.__max_ping = 0
				self.__min_ping = 0
				self.__last_error = 0
				self.__targets = curtarg
			
			fail, output = commands.getstatusoutput("ping -c 1 %s" % curtarg)
			if (fail): output = ""
			
			if (fail==0):
				self.__last_error = 0
				output = output.splitlines()
				goodline = output[1]
				self.__last_ping = float(goodline.split(" ")[6].split("=")[1])
				
				if self.__last_ping > self.__max_ping:
					self.__max_ping = self.__last_ping
				
				if self.__last_ping < self.__min_ping or self.__min_ping == 0.0:
					self.__min_ping = self.__last_ping
			else:
				self.__last_error = 1
				
			time.sleep(self._get_config("update")*0.001)


def new_sensor(args): return apply(Ping, args)
